﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.IO;
using System.Web.Script.Serialization;
using GridEditWithUpload.Models;

namespace GridEditWithUpload.Controllers
{
    public class HomeController : Controller
    {
        public ActionResult EmployeePhoto()
        {
            return View();
        }

        //Provide grid datasource
        public ActionResult GetEmployeeData()
        {

            return Json(new { result = new NorthwindDataContext().EmployeePhotos.ToList() }, JsonRequestBehavior.AllowGet);

        }

        //Perform file insertion 
        public void PerformInsert(EmployeeInsertModel employee)
        {

            NorthwindDataContext db = new NorthwindDataContext();
            if (employee.EmployeeID != 0)
            {
                db.EmployeePhotos.InsertOnSubmit(new EmployeePhoto()
                {
                    EmployeeID = employee.EmployeeID,
                    Name = employee.Name,
                    Photo = employee.Photo != null ? GetByteStream(employee.Photo) : null
                });
                db.SubmitChanges();
            }
        }

        //Perform update
        public void PerformUpdate(EmployeeInsertModel employee)
        {

            NorthwindDataContext db = new NorthwindDataContext();

            EmployeePhoto emp = (EmployeePhoto)db.EmployeePhotos.Single(s => s.EmployeeID == employee.EmployeeID);

            emp.EmployeeID = employee.EmployeeID;
            emp.Name = employee.Name;
            emp.Photo = employee.Photo != null ? GetByteStream(employee.Photo) : null;

            db.SubmitChanges();

        }

        //Perform delete
        public void PerformDelete(int key, string keyColumn)
        {

            NorthwindDataContext db = new NorthwindDataContext();

            EmployeePhoto emp = (EmployeePhoto)db.EmployeePhotos.Single(s => s.EmployeeID == key);

            db.EmployeePhotos.DeleteOnSubmit(emp);

            db.SubmitChanges();
        }

        //Convert the posted file to byte[] 
        public byte[] GetByteStream(HttpPostedFileBase file)
        {

            byte[] bt = new byte[file.InputStream.Length];
            MemoryStream ms = new MemoryStream();
            ms.Read(bt, 0, (int)file.InputStream.Length);
            return bt;
        }
        public void SaveDefault(IEnumerable<HttpPostedFileBase> EmployeeGridPhoto)
        {
            foreach (var file in EmployeeGridPhoto)
            {
                var fileName = Path.GetFileName(file.FileName);
                var destinationPath = Path.Combine(Server.MapPath("~/Content/ejThemes/images/Employees"), fileName);
                file.SaveAs(destinationPath);
            }
        }
        public void RemoveDefault(string[] fileNames)
        {
            foreach (var fullName in fileNames)
            {
                var fileName = Path.GetFileName(fullName);
                var physicalPath = Path.Combine(Server.MapPath("~/Content/ejThemes/images/Employees"), fileName);
                if (System.IO.File.Exists(physicalPath))
                {
                    System.IO.File.Delete(physicalPath);
                }
            }
        }
    }

    //ViewModel to hold FormData from grid.
    public class EmployeeInsertModel
    {

        public int EmployeeID { get; set; }
        public string Name { get; set; }
        public HttpPostedFileBase Photo { get; set; }
    }

}